@@ -28,7 +28,6 @@ from form_utils.forms import BetterModelForm
 from tinymce.widgets import TinyMCE
 from tendenci.core.payments.models import PaymentMethod
 from tendenci.core.perms.forms import TendenciBaseForm
-from tinymce.widgets import TinyMCE
 from tendenci.core.base.fields import SplitDateTimeField, EmailVerificationField
 from tendenci.core.emails.models import Email
 from tendenci.core.site_settings.utils import get_setting
@@ -639,6 +638,10 @@ class PlaceForm(forms.ModelForm):
             'country',
             'url',
         ]
+        if self.instance.id:
+            self.fields['description'].widget.mce_attrs['app_instance_id'] = self.instance.id
+        else:
+            self.fields['description'].widget.mce_attrs['app_instance_id'] = 0
 
     def save(self, *args, **kwargs):
         place = super(PlaceForm, self).save(commit=False)
@@ -696,6 +699,12 @@ class SpeakerForm(BetterModelForm):
           })
         ]
 
+    def __init__(self, *args, **kwargs):
+        super(SpeakerForm, self).__init__(*args, **kwargs)
+        if self.instance.id:
+            self.fields['description'].widget.mce_attrs['app_instance_id'] = self.instance.id
+        else:
+            self.fields['description'].widget.mce_attrs['app_instance_id'] = 0
 
 class OrganizerForm(forms.ModelForm):
     description = forms.CharField(required=False,
@@ -712,6 +721,13 @@ class OrganizerForm(forms.ModelForm):
             'description',
         )
 
+    def __init__(self, *args, **kwargs):
+        super(OrganizerForm, self).__init__(*args, **kwargs)
+        if self.instance.id:
+            self.fields['description'].widget.mce_attrs['app_instance_id'] = self.instance.id
+        else:
+            self.fields['description'].widget.mce_attrs['app_instance_id'] = 0
+
 
 class PaymentForm(forms.ModelForm):
     class Meta:
@@ -829,6 +845,10 @@ class Reg8nEditForm(BetterModelForm):
         initial=[1,2,3]) # first three items (inserted via fixture)
     use_custom_reg = UseCustomRegField(label="Custom Registration Form")
 
+    registration_email_text = forms.CharField(required=False,
+        widget=TinyMCE(attrs={'style':'width:100%'},
+        mce_attrs={'storme_app_label':RegistrationConfiguration._meta.app_label,
+        'storme_model':RegistrationConfiguration._meta.module_name.lower()}))
 
     class Meta:
         model = RegistrationConfiguration
@@ -907,8 +927,10 @@ class Reg8nEditForm(BetterModelForm):
             self.fields['reminder_days'].help_text = '%s<br /><br />%s' % \
                                         (self.fields['reminder_days'].help_text,
                                          reminder_edit_link)
+            self.fields['registration_email_text'].widget.mce_attrs['app_instance_id'] = self.instance.id
         else:
             self.fields['use_custom_reg'].initial =',0,1'
+            self.fields['registration_email_text'].widget.mce_attrs['app_instance_id'] = 0
 
         #.short_text_input
         self.fields['reminder_days'].initial = '7,1'
@@ -1494,6 +1516,10 @@ class MessageAddForm(forms.ModelForm):
 
     def __init__(self, event_id=None, *args, **kwargs):
         super(MessageAddForm, self).__init__(*args, **kwargs)
+        if self.instance.id:
+            self.fields['body'].widget.mce_attrs['app_instance_id'] = self.instance.id
+        else:
+            self.fields['body'].widget.mce_attrs['app_instance_id'] = 0
 
 class EmailForm(forms.ModelForm):
     #events = forms.CharField()
@@ -1512,6 +1538,10 @@ class EmailForm(forms.ModelForm):
 
     def __init__(self, *args, **kwargs):
         super(EmailForm, self).__init__(*args, **kwargs)
+        if self.instance.id:
+            self.fields['body'].widget.mce_attrs['app_instance_id'] = self.instance.id
+        else:
+            self.fields['body'].widget.mce_attrs['app_instance_id'] = 0
 
 class PendingEventForm(EventForm):
     class Meta:
