@@ -351,6 +351,11 @@ BROKER_PASSWORD = "guest"
 BROKER_VHOST = "/"
 CELERY_IS_ACTIVE = False
 
+# USE_SUBPROCESS - in places like exports and long-running
+# processes that can timeout, subprocess will be used
+# if this setting is True
+USE_SUBPROCESS = True
+
 # --------------------------------------#
 # Hackstack Search
 # --------------------------------------#
